==> kubernetes-model-apps-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DeploymentListFluent<A extends DeploymentListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Deployment item);
  public A setToItems(Integer index,Deployment item);
  public A addToItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public A addAllToItems(Collection<Deployment> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public A removeAllFromItems(Collection<Deployment> items);
  public A removeMatchingFromItems(Predicate<DeploymentBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Deployment> getItems();
  public List<Deployment> buildItems();
  public Deployment buildItem(Integer index);
  public Deployment buildFirstItem();
  public Deployment buildLastItem();
  public Deployment buildMatchingItem(Predicate<DeploymentBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DeploymentBuilder> predicate);
  public A withItems(List<Deployment> items);
  public A withItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public Boolean hasItems();
  public DeploymentListFluent.ItemsNested<A> addNewItem();
  public DeploymentListFluent.ItemsNested<A> addNewItemLike(Deployment item);
  public DeploymentListFluent.ItemsNested<A> setNewItemLike(Integer index,Deployment item);
  public DeploymentListFluent.ItemsNested<A> editItem(Integer index);
  public DeploymentListFluent.ItemsNested<A> editFirstItem();
  public DeploymentListFluent.ItemsNested<A> editLastItem();
  public DeploymentListFluent.ItemsNested<A> editMatchingItem(Predicate<DeploymentBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DeploymentFluent<DeploymentListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-apps-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DeploymentListFluent<A extends DeploymentListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Deployment item);
  public A setToItems(int index,Deployment item);
  public A addToItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public A addAllToItems(Collection<Deployment> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public A removeAllFromItems(Collection<Deployment> items);
  public A removeMatchingFromItems(Predicate<DeploymentBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Deployment> getItems();
  public List<Deployment> buildItems();
  public Deployment buildItem(int index);
  public Deployment buildFirstItem();
  public Deployment buildLastItem();
  public Deployment buildMatchingItem(Predicate<DeploymentBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DeploymentBuilder> predicate);
  public A withItems(List<Deployment> items);
  public A withItems(io.fabric8.kubernetes.api.model.apps.Deployment... items);
  public Boolean hasItems();
  public DeploymentListFluent.ItemsNested<A> addNewItem();
  public DeploymentListFluent.ItemsNested<A> addNewItemLike(Deployment item);
  public DeploymentListFluent.ItemsNested<A> setNewItemLike(int index,Deployment item);
  public DeploymentListFluent.ItemsNested<A> editItem(int index);
  public DeploymentListFluent.ItemsNested<A> editFirstItem();
  public DeploymentListFluent.ItemsNested<A> editLastItem();
  public DeploymentListFluent.ItemsNested<A> editMatchingItem(Predicate<DeploymentBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DeploymentFluent<DeploymentListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
